/*
       Licensed to the Apache Software Foundation (ASF) under one
       or more contributor license agreements.  See the NOTICE file
       distributed with this work for additional information
       regarding copyright ownership.  The ASF licenses this file
       to you under the Apache License, Version 2.0 (the
       "License"); you may not use this file except in compliance
       with the License.  You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing,
       software distributed under the License is distributed on an
       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
       KIND, either express or implied.  See the License for the
       specific language governing permissions and limitations
       under the License
*/
/**
 * Sample.java
 *
 *
 * Created: Mon Feb 19 17:56:13 2001
 *
 * @author Valter Crescenzi
 * @version
 */
package roadrunner;

import java.io.*;
import java.net.*;
import java.util.*;
import java.util.logging.*;

import org.xml.sax.SAXException;

import roadrunner.config.Preferences;
import roadrunner.parser.Lexer;
import roadrunner.parser.TokenList;

public class Sample  {
    
    static private Logger log = Logger.getLogger(Sample.class.getName());
    
    private URL url;
    private TokenList tokens;
    private IdentityHashMap token2bb;
    
    public Sample(URL url, Preferences options) throws IOException, SAXException {
        this.url = url;
        log.fine("Reading "+this.getURL());
        Reader source = new BufferedReader(new InputStreamReader(getURL().openStream()));
        Lexer lexer = new Lexer(source,options);
        this.tokens = new TokenList(lexer.getTokens());
        this.token2bb = lexer.getTokens2BoundingBoxes();
        source.close();
    }
    
    public URL getURL() {
        return this.url;
    }
    
    public TokenList getTokenlist() {
        return this.tokens;
    }
    
    public String getName() {
        return stripExtension(new File(this.getURL().getFile()).getName());
    }
    
    private String stripExtension(String s) {
        int index = s.lastIndexOf('.');
        return ( index!=-1 ? s.substring(0,index) : s);
    }
    
    public int getDL() {
        return getTokenlist().getDL();
    }
    
    public IdentityHashMap getTokens2BoundingBoxes() {
        return this.token2bb;
    }
    
    public String toString() {
        return this.getURL().toString();
    }
    
} // Sample
