/*
       Licensed to the Apache Software Foundation (ASF) under one
       or more contributor license agreements.  See the NOTICE file
       distributed with this work for additional information
       regarding copyright ownership.  The ASF licenses this file
       to you under the Apache License, Version 2.0 (the
       "License"); you may not use this file except in compliance
       with the License.  You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing,
       software distributed under the License is distributed on an
       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
       KIND, either express or implied.  See the License for the
       specific language governing permissions and limitations
       under the License
*/
/**
 * ASTVariant.java
 * Created: 
 *
 * @author  Valter Crescenzi
 * @version
 */
package roadrunner.ast;

import java.util.*;

import roadrunner.parser.Token;

public class ASTVariant extends NodeAdapter implements Node, Matchable {
    
    private List samples;
    private String label;
    
    private Token sampleToken;
    
    ASTVariant(Token token) {
        super(ASTConstants.JJTVARIANT);
        this.sampleToken = token;
        this.samples = new ArrayList();
        this.label = null;
    }
    
    /** Accept the visitor. **/
    public boolean jjtAccept(Visitor visitor) {
        return visitor.visit(this);
    }
    
    public Token getToken() {
        return this.sampleToken;
    }
    
    public boolean matches(Token t) {
        return this.getToken().matches(t);
    }
    
    public int depth() {
        return getToken().depth();
    }
    
    public int code() {
        return getToken().code();
    }
    public void setLabel(String label) {
        this.label = label;
    }
    
    public String getLabel() {
        return this.label;
    }
    
    public void setSamples(Set strings) {
        this.samples.addAll(strings);
    }
    
    public List getSamples() {
        return this.samples;
    }
    
    public String toString() {
        List samples = getSamples();
        Object sample = (!samples.isEmpty() ? (Object)samples : getToken() );
        return "*" + " ( "+getLabel()+" ) " + sample;
    }
    
    public boolean equals(Object o) {
        if (!super.equals(o)) return false;
        ASTVariant that = (ASTVariant)o;
        return this.getToken().code()==that.getToken().code() && 
               this.getToken().depth()==that.getToken().depth();
    }
    
    public int hashCode() {
        return this.getToken().hashCode();
    }
    
    
}
