/*
       Licensed to the Apache Software Foundation (ASF) under one
       or more contributor license agreements.  See the NOTICE file
       distributed with this work for additional information
       regarding copyright ownership.  The ASF licenses this file
       to you under the Apache License, Version 2.0 (the
       "License"); you may not use this file except in compliance
       with the License.  You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing,
       software distributed under the License is distributed on an
       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
       KIND, either express or implied.  See the License for the
       specific language governing permissions and limitations
       under the License
*/
/*
 * Visitor.java
 * java.util.List based implementation of Composite pattern
 * Created on 
 * @author  Valter Crescenzi
 */

package roadrunner.ast;

import java.util.List;
import java.util.Iterator;
import java.util.ArrayList;


public class SimpleNode extends NodeAdapter implements Node, Cloneable {
    
    private List children;
    
    protected SimpleNode(int id) {
        super(id);
        this.children = makeChildren();
    }
    
    protected SimpleNode(int id, List children) {
        super(id);
        this.children = children;
    }
    
    final private void checkIndex(int i) {
        if (i<0 || i>=children.size())
            throw new NoSuchNodeException("The child number "+i+" doesn\'t exist!");
    }
    
    public Node jjtGetChild(int i) {
        checkIndex(i);
        return (Node)children.get(i);
    }
    
    public int jjtGetNumChildren() {
        return children.size();
    }
    
    public List jjtGetChildren() {
        return this.children;
    }

    public Node clone(boolean deep) {
        SimpleNode clone=null;
        try {
            clone = (SimpleNode)this.clone();
            if (deep) {
                clone.children = makeChildren();
                Iterator it = this.children.iterator();
                while (it.hasNext()) {
                    Node child = (Node)it.next();
                    clone.children.add(child.clone(deep));
                }
            }
            else clone.children = makeChildren(this.children);
        }
        catch (CloneNotSupportedException cnse) {
            System.out.print(cnse.getMessage());
            cnse.printStackTrace();
            System.exit(-1);
        }
        return clone;
    }
    
    private List makeChildren()          {  return new ArrayList();     }
    private List makeChildren(List kids) {  return new ArrayList(kids); }
    
}
