/*
       Licensed to the Apache Software Foundation (ASF) under one
       or more contributor license agreements.  See the NOTICE file
       distributed with this work for additional information
       regarding copyright ownership.  The ASF licenses this file
       to you under the Apache License, Version 2.0 (the
       "License"); you may not use this file except in compliance
       with the License.  You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing,
       software distributed under the License is distributed on an
       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
       KIND, either express or implied.  See the License for the
       specific language governing permissions and limitations
       under the License
*/
/*
 * Walker.java
 *
 * Created on 22 gennaio 2003, 11.31
 * @author  Valter Crescenzi
 */

package roadrunner.ast;

import java.util.ListIterator;

import roadrunner.bidi.Region;
import roadrunner.bidi.*;

public class Walker extends VisitorPlugger implements Visitor {
    
  private IteratorsStack iteratorsStack;
  protected Region region;
  
  /** Creates a new instance of Walker */
  protected Walker(Expression exp) {
      this(exp.asRegion());
  }
  protected Walker(Region region) {
    this(region, Direction.LEFT2RIGHT);
  }
  protected Walker(Region region, Direction dir) {
    super(dir);
    this.region = region;
    this.iteratorsStack = new IteratorsStack();
  }
  
  // N.B. to update correctly the iterators used by path getters, visitors deriving from this class
  // MUST invoke either directly or by means of methods
  // visitNode(node), visitChildren(node), visitList(list) inside VisitorPlugger  one of the following two methods 
  protected void startVisitingList(ListIterator lit) {
    this.iteratorsStack.register(lit);
  }
  protected void   endVisitingList(ListIterator lit) {
    this.iteratorsStack.unregister(lit);      
  }
  
 /**
   *  Return the absolute path of the node currently visited
   */  
  protected Node.Path getCurrentAbsolutePath() {
    return ((ExpressionRegion)this.region).getAbsolutePath(new PathArray(this.iteratorsStack.makeIndices()));
  }

 /**
   *  Return the path relative to the region visited
   */  
  protected Node.Path getCurrentRelativePath() {
    return new PathArray(this.iteratorsStack.makeIndices());
  }
}
