/*
       Licensed to the Apache Software Foundation (ASF) under one
       or more contributor license agreements.  See the NOTICE file
       distributed with this work for additional information
       regarding copyright ownership.  The ASF licenses this file
       to you under the Apache License, Version 2.0 (the
       "License"); you may not use this file except in compliance
       with the License.  You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing,
       software distributed under the License is distributed on an
       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
       KIND, either express or implied.  See the License for the
       specific language governing permissions and limitations
       under the License
*/
/*
 * CharacteristicSample.java
 * @author  Valter Crescenzi
 * Created on 14 ottobre 2003, 14.29
 */

package roadrunner.engine.sampler;

import java.util.*;
import java.util.logging.*;

import roadrunner.bidi.*;
import roadrunner.ast.ExpressionRegion;
import roadrunner.parser.Parser;
import roadrunner.parser.Token;
import roadrunner.parser.TokenList;

public class CharacteristicSample extends TokenList {
    
    static private Logger log = Logger.getLogger(CharacteristicSample.class.getName());
    
    private Region region;
    private Direction dir;
    
    private BidirectionalList sampled;
    
    /** Creates a new instance of CharacteristicSample */
    CharacteristicSample(Region region, Direction dir) {
        this.region = region;
        this.dir = dir;
        this.tokens = new ArrayList(Math.max(region.size(), 16));
        this.sampled = BidirectionalListFactory.newListView(dir, this.tokens);
    }
    
    private CharacteristicSample(Region region, TokenList alreadySampled, Direction dir) {
        super(alreadySampled.getTokens());
        this.region = region;
        this.dir = dir;
        this.sampled = null;
    }
    
    public Region getRegion() {
        return this.region;
    }
    
    void addToken(Token token) {
        this.sampled.add(token);
    }
    
    public CharacteristicSample getProjectedSampleRemainingAfterPos(Direction dir, int pos) {
        //N.B. pos is a position on the sample, not on the region sampled
        Region tokenlistRegion = this.asRegion();
        TokenList tokenlistBeforePos = new TokenList(dir.subRegionBefore(tokenlistRegion, pos).asList());
        TokenList tokenlistAfterPos = new TokenList(dir.subRegionAfter(tokenlistRegion, pos).asList());
        Parser parser = new Parser(this.region, dir);
        if (!parser.parseAllTokenlist(tokenlistBeforePos)) {
            log.fine("portion of characteristic sample doesn't match with the generating exp!\n"+
                     "Region:  "+this.region+"\nPortion: "+tokenlistBeforePos);
            return null;
        }
        ExpressionRegion remainingRegion = parser.getRemainingRegion();
        return new CharacteristicSample(remainingRegion, tokenlistAfterPos, dir);
    }
    
    
}
