/*
       Licensed to the Apache Software Foundation (ASF) under one
       or more contributor license agreements.  See the NOTICE file
       distributed with this work for additional information
       regarding copyright ownership.  The ASF licenses this file
       to you under the Apache License, Version 2.0 (the
       "License"); you may not use this file except in compliance
       with the License.  You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing,
       software distributed under the License is distributed on an
       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
       KIND, either express or implied.  See the License for the
       specific language governing permissions and limitations
       under the License
*/
/*
 * SpaceOptions.java
 *
 * Created on December 30, 2003, 2:37 PM
 * @author  Valter Crescenzi
 */

package roadrunner.engine.space;

import roadrunner.config.Constants;
import roadrunner.config.Config;

public class SpaceOptions implements Constants {

    //enabled operators 
    private boolean hookEnabled;
    private boolean plusEnabled;
    private boolean subtreeEnabled;
    private boolean freePlus;
    
    //enable collapse backtracking
    private boolean collapsingBckt; 

    private int llk; //force expression to be LL(k)
    private int rrk; //force expression to be "RR(k)" (i. e. LL(k) with direction <- )

    //number of DOM depth at which introducing ambiguity mismatches
    private int ambiguity;   

    //minimum DOM depth to apply addSubtree operator
    private int minDOMdepth;
    
    //maximum number of states in a search space
    private int maxStates;
        
    /** Creates a new instance of SpaceOptions */
    public SpaceOptions(int minDOMdepth4subtrees) {
        this.hookEnabled    = Config.getPrefs().getBoolean(HOOK);
        this.plusEnabled    = Config.getPrefs().getBoolean(PLUS);
        this.subtreeEnabled = Config.getPrefs().getBoolean(SUBTREE);
        this.freePlus       = Config.getPrefs().getBoolean(FREE_PLUS);
        this.collapsingBckt = Config.getPrefs().getBoolean(CBACKTRACKING);
        this.ambiguity      = Config.getPrefs().getInt(AMBIGUITY);
        this.llk            = Config.getPrefs().getInt(LLK); 
        this.rrk            = Config.getPrefs().getInt(RRK);
        this.maxStates      = Config.getPrefs().getInt(MAX_STATES);
        this.minDOMdepth    = minDOMdepth4subtrees;
    }
        
    public int getAmbiguity() {
        return this.ambiguity;
    }

    public boolean isHookEnabled() {
        return this.hookEnabled;
    }

    public boolean isPlusEnabled() {
        return this.plusEnabled;
    }

    public boolean isSubtreeEnabled() {
        return this.subtreeEnabled;
    }

    public boolean isPlusFree() {
        return this.freePlus;
    }

    public int getMinDOMdepth() {
        return this.minDOMdepth;
    }

    public boolean isCollapsingBacktrackingEnabled() {
        return this.collapsingBckt;
    }

    public int getLLK() {
        return this.llk;
    }

    public int getRRK() {
        return this.rrk;
    }
    
    public int getMaxNumberOfStates() {
        return this.maxStates;
    }
}
