/*
       Licensed to the Apache Software Foundation (ASF) under one
       or more contributor license agreements.  See the NOTICE file
       distributed with this work for additional information
       regarding copyright ownership.  The ASF licenses this file
       to you under the Apache License, Version 2.0 (the
       "License"); you may not use this file except in compliance
       with the License.  You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing,
       software distributed under the License is distributed on an
       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
       KIND, either express or implied.  See the License for the
       specific language governing permissions and limitations
       under the License
*/
/*
 *  SimpleOperator.java
 *
 * Created on 23 marzo 2003, 15.09
 * @author  Valter Crescenzi
 */

package roadrunner.engine.space.operator;

import roadrunner.bidi.Direction;
import roadrunner.ast.Expression;
import roadrunner.ast.ExpressionRegion;
import roadrunner.parser.MismatchPoint;
import roadrunner.util.Indenter;
import roadrunner.engine.ExpressionIterator;
import roadrunner.engine.space.SearchSpace;
import roadrunner.engine.space.Operator;

abstract class SimpleOperator extends ExpressionIterator implements Operator {
    
    protected Direction dir;
    protected MismatchPoint mismatch;
    protected boolean expired;
    protected SearchSpace space;
    
    /** Creates a new instance of SimpleOperator */
    protected SimpleOperator(MismatchPoint mismatch) {
        this.mismatch = mismatch;
        this.dir = this.mismatch.getDir();
        this.expired = false;
        this.space = mismatch.getSearchSpace();
    }
    
    protected MismatchPoint getMismatch() {
        return this.mismatch;
    }
        
    abstract Expression compute();
    
    abstract ExpressionRegion getExtension(); // Region which will be changed by this operator
    
    protected Expression computeNext() {
        if (this.expired) return null;
        else return compute();
    }
    
    boolean isExpired() {
        return this.expired;
    }
    
    String toString(Indenter ind) {
        return ind+this.mismatch.toString()+": "+this.getClass().getName();
    }
    
    abstract public int h();
    
    public int compareTo(Object o) {
        // low h() is better
        SimpleOperator op = (SimpleOperator)o;
        int result = this.h()-op.h();
        return (result!=0 ? result : this.id-op.id);// be consistent with equals()
    }
    
    public String toString() {
        Indenter ind = new Indenter(0,this.dir.toString()+" ",false);
        return toString(ind);
    }
    
}
