/*
       Licensed to the Apache Software Foundation (ASF) under one
       or more contributor license agreements.  See the NOTICE file
       distributed with this work for additional information
       regarding copyright ownership.  The ASF licenses this file
       to you under the Apache License, Version 2.0 (the
       "License"); you may not use this file except in compliance
       with the License.  You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing,
       software distributed under the License is distributed on an
       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
       KIND, either express or implied.  See the License for the
       specific language governing permissions and limitations
       under the License
*/
/**
 * addHook_w.java
 *
 * Created on 23 marzo 2003, 17.28
 * @author  Valter Crescenzi
 */
package roadrunner.engine.space.operator;

import java.util.logging.*;

import roadrunner.bidi.Region;
import roadrunner.ast.Expression;
import roadrunner.ast.ExpressionRegion;
import roadrunner.parser.MismatchPoint;
import roadrunner.parser.Token;
import roadrunner.engine.space.Operator;

class addHook_w extends SquareOperator implements Operator {
    
    static private Logger log = Logger.getLogger(addHook_w.class.getName());
    
    private final static int MAX_MATCHING_BORDER_TOKENS = 16;
    
    private static class Factory extends SquareOperatorFactory {
        
        private Factory(MismatchPoint m) {
            super(m);
        }
        
        Operator createOperator(int k) {
            return new addHook_w(this.m, getSearcher(), getSquare(k), k);
        }
        
        Region getRegionToSearch() {
            return m.getMismatchingExpression();
        }
        
        Token getTagWanted() {
            return m.getFirstMismatchingToken();
        }
        
        Region getSquare(int k) {
            return getSearcher().getRegionBeforeOccurrence(k-1);
        }
        
    }
    
    static OperatorFactory getFactory(MismatchPoint m) {
        return new Factory(m);
    }
    
    addHook_w(MismatchPoint mismatch, Searcher searcher, Region square, int k) {
        super(mismatch,searcher,square,k);
        this.lenOfMatchingBorder = countMatchingBorder(this.dir, getRegionAfterSquare(), mismatch.getMismatchingTokenlist(),MAX_MATCHING_BORDER_TOKENS);
    }
    
    protected Expression compute() {
        this.expired = true; // just one result
        return mismatch.getExpression().addHook((ExpressionRegion)square, new Expression(square));
    }
    
    protected Expression getCandidateSquare() {
        return new Expression(getSquare());
    }
    
    protected Region getRegionAfterSquare() {
        return getSearcher().getRegionFromOccurrence(k-1);
    }
    
    protected ExpressionRegion getExtension() {
        return (ExpressionRegion)square;
    }
    
} // addHook_w Operator
