/*
       Licensed to the Apache Software Foundation (ASF) under one
       or more contributor license agreements.  See the NOTICE file
       distributed with this work for additional information
       regarding copyright ownership.  The ASF licenses this file
       to you under the Apache License, Version 2.0 (the
       "License"); you may not use this file except in compliance
       with the License.  You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing,
       software distributed under the License is distributed on an
       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
       KIND, either express or implied.  See the License for the
       specific language governing permissions and limitations
       under the License
*/
/*
 * Matrix.java
 *
 * Created on January 29, 2004, 9:57 PM
 * @author  Luigi Arlotta, Valter Crescenzi
 */

package roadrunner.labeller;

import java.util.*;

import roadrunner.ast.*;
import roadrunner.util.Util;

public class Matrix {
    
    private List candidateVariants;   //these variants can be labelled
    private List candidateInvariants; //these invariants can be used as labels
    
    /** Creates a new instance of Matrix */
    public Matrix(Expression exp) {
        this.candidateVariants   = findCandidateVariants(exp);
        this.candidateInvariants = findCandidateInvariants(exp);
    }
    
    private List findCandidateVariants(Expression exp) {
        List candidates = new LinkedList();
        Iterator it = exp.getVariants().iterator();
        while (it.hasNext()) {
            ASTVariant variant = (ASTVariant)it.next();
            if (variant.getToken().isPCDATA()) {
                candidates.add(variant);
            }
        }
        return candidates;
    }
    
    private List findCandidateInvariants(Expression exp) {
        List candidates = new LinkedList();
        Iterator it = exp.getInvariants().iterator();
        while (it.hasNext()) {
            ASTToken invariant = (ASTToken)it.next();
            // check the candidate label 
            if (LabelExtractor.trimLabel(invariant.getText()).length()!=0) {
                candidates.add(invariant);
            }
        }
        return candidates;
    }
    
    public List getCandidateVariants()   { return this.candidateVariants;   }
    public List getCandidateInvariants() { return this.candidateInvariants; }
    
    public ASTVariant getVariant(int i) {
        return (ASTVariant)getCandidateVariants().get(i);
    }
    
    public ASTToken getInvariant(int j) {
        return (ASTToken)getCandidateInvariants().get(j);
    }
    
    public int getNumberOfVariants()   { return this.candidateVariants.size();   }
    public int getNumberOfInvariants() { return this.candidateInvariants.size(); }
    
}
