/*
       Licensed to the Apache Software Foundation (ASF) under one
       or more contributor license agreements.  See the NOTICE file
       distributed with this work for additional information
       regarding copyright ownership.  The ASF licenses this file
       to you under the Apache License, Version 2.0 (the
       "License"); you may not use this file except in compliance
       with the License.  You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing,
       software distributed under the License is distributed on an
       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
       KIND, either express or implied.  See the License for the
       specific language governing permissions and limitations
       under the License
*/
/*
 * TokenList.java
 *
 * Created on 23 gennaio 2003, 16.08
 * @author  Valter Crescenzi
 */

package roadrunner.parser;


import java.util.*;

import roadrunner.engine.MDLEvaluator;

public class TokenList {
    
    /** Creates a new instance of TokenList */    
    protected List tokens;
    private int dl;
    
    public TokenList(List tokens) {
        this.tokens = Collections.unmodifiableList(tokens);
        this.dl = -1;
    }
    protected TokenList() {
        this.dl = -1;
    }
    
    public List getTokens() {
        return this.tokens;
    }
    
    public Token getToken(int index) {
        return (Token)this.tokens.get(index);
    }
    
    public TokenListRegion asRegion() {
        return new TokenListRegion(this);
    }
    
    public int size() {
        return this.tokens.size();
    }
    
    public int getDL() {
        this.dl = (this.dl == -1 ? MDLEvaluator.getTokenlistDL(this) : this.dl);
        return this.dl;
    }
    
    public String toString() {
        return "\t\n(TL: "+asRegion().toString()+")";
    }
    
    // N.B. other classes (like Binder) expect that the equals() method of TokenList is not redefined
}
