/*
       Licensed to the Apache Software Foundation (ASF) under one
       or more contributor license agreements.  See the NOTICE file
       distributed with this work for additional information
       regarding copyright ownership.  The ASF licenses this file
       to you under the Apache License, Version 2.0 (the
       "License"); you may not use this file except in compliance
       with the License.  You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing,
       software distributed under the License is distributed on an
       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
       KIND, either express or implied.  See the License for the
       specific language governing permissions and limitations
       under the License
*/
/*
 * TextToken.java
 *
 * Created on December 25, 2003, 12:22 PM
 * @author  Valter Crescenzi
 */

package roadrunner.parser.token;

import java.util.Map;

import roadrunner.ast.ASTToken;
import roadrunner.parser.Token;

class TextToken extends ASTToken implements Token {
    
    /** Thanks to these two inner classes we can mark TextToken and TagTag's constructors
     *  as private to avoid that Tokens are created bypassing this TokenFactory */
    private String text;

    /** Creates a new instance of TextToken */
    TextToken(String text, int depth) {
        super(depth,0);
        this.text = text;
    }
    
    public boolean isIMG()     { return false; }
    public boolean isLink()    { return false; }
    
    public String getText()    { return this.text; }
    public String getElement() { throw new RuntimeException("This object is supposed to be a text Token!"); }
    public Map getAttributes() { throw new RuntimeException("This object is supposed to be a text Token!"); }
    
    public String getVariantValue() { return this.getText(); }
    
    /* N.B. In order for these objects to be used both as tokens of samples and as leaves of expressions ,*/    
    /*  methods equals() and hashCode() must obey to the semantics of ASTToken's */
    public String toString()     { return getText();     }
}
