/*
       Licensed to the Apache Software Foundation (ASF) under one
       or more contributor license agreements.  See the NOTICE file
       distributed with this work for additional information
       regarding copyright ownership.  The ASF licenses this file
       to you under the Apache License, Version 2.0 (the
       "License"); you may not use this file except in compliance
       with the License.  You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing,
       software distributed under the License is distributed on an
       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
       KIND, either express or implied.  See the License for the
       specific language governing permissions and limitations
       under the License
*/
/*
 * DOMLoader.java
 * Class to load DOM Document from HTML and XML sources.
 * Call Tidy to load non well-formed HTML documents.
 *
 * Created on 2 marzo 2003, 20.59
 * @author  Valter Crescenzi
 */

package roadrunner.util;

import java.io.*;
import java.util.logging.*;
import org.w3c.dom.*;
import org.xml.sax.*;
import javax.xml.parsers.*;

import org.cyberneko.html.parsers.DOMParser;
import org.xml.sax.InputSource;
import org.apache.xerces.xni.parser.XMLDocumentFilter;
import org.cyberneko.html.filters.Identity;
import org.cyberneko.html.filters.Purifier;

public class DOMLoader {
    
    static final private Logger log = Logger.getLogger(DOMLoader.class.getName());
    
    static public Document parseXML(InputStream in) throws SAXException, IOException {
        return parseXML(new InputSource(in));
    }
    
    static public Document parseXML(Reader in) throws SAXException, IOException {
        return parseXML(new InputSource(in));
    }
    
    static public Document parseXML(InputSource in) throws SAXException, IOException {
        return getDocumentBuilder().parse(in);
    }
    
    static public Document parseHTML(Reader in) throws SAXException, IOException {
        DOMParser parser = new DOMParser();
        parser.setFeature("http://xml.org/sax/features/namespaces", false);
        parser.setFeature("http://cyberneko.org/html/features/balance-tags", true);
        XMLDocumentFilter[] filters = { new Purifier() };
        parser.setProperty("http://cyberneko.org/html/properties/filters", filters);
        parser.parse(new InputSource(in));
        return parser.getDocument();
    }
    
    static public DocumentBuilder getDocumentBuilder() {
        try {
            DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
            factory.setIgnoringComments(false);
            factory.setExpandEntityReferences(true);
            factory.setValidating(false);
            factory.setIgnoringElementContentWhitespace(true);
            DocumentBuilder parser = factory.newDocumentBuilder();
            parser.setEntityResolver(new EntityResolver() {
                public InputSource resolveEntity(String publicId, String systemId) {
                    if (systemId.endsWith(".dtd"))
                        // this deactivates all DTDs by giving empty XML docs
                        return new InputSource(new ByteArrayInputStream("<?xml version='1.0' encoding='ISO-8859-1'?>".getBytes()));
                    else return null;
                }
            });
            return parser;
        }
        catch (ParserConfigurationException pce) {
            log.severe("DOM Parser Misconfiguration"+pce);
            System.exit(-1);
            return null;
        }
    }
    
}