/*
       Licensed to the Apache Software Foundation (ASF) under one
       or more contributor license agreements.  See the NOTICE file
       distributed with this work for additional information
       regarding copyright ownership.  The ASF licenses this file
       to you under the Apache License, Version 2.0 (the
       "License"); you may not use this file except in compliance
       with the License.  You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing,
       software distributed under the License is distributed on an
       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
       KIND, either express or implied.  See the License for the
       specific language governing permissions and limitations
       under the License
*/
/*
 * Indenter.java
 * Created on 
 * @author  Valter Crescenzi
 */

package roadrunner.util;

import java.util.Stack;

public class Indenter {
    
    final private static String INDENT_UNIT = "  ";
    
    public int indent;
    private String prefix;
    private Stack stack;
    private int index;
    private boolean numbering;
    
    public Indenter() {
        this(0,"",false);
    }
    public Indenter(int start) {
        this(start,"",false);
    }
    public Indenter(String prefix) {
        this(0,prefix, false);
    }
    public Indenter(boolean numbering) {
        this(0,"",numbering);
    }
    
    public Indenter(int ind, String prefix, boolean numbering) {
        this.indent = ind;
        this.prefix = prefix;
        this.stack  = new Stack();
        this.index  = 0;
        this.numbering = numbering;
    }
    
    private String indentString(int i) {
        StringBuffer result = new StringBuffer(i*INDENT_UNIT.length());
        for(int k=0; k<i; k++) {
            result.append(INDENT_UNIT);
        }
        return result.toString();
    }
    public String toString() {
        return prefix+indentString(this.indent)+ (numbering? (index++)+"." : "");
    }
    public void inc() {
        if (numbering) {
            this.stack.push(new Integer(index));
            this.index = 0;
        }
        ++this.indent;
    }
    public void dec() {
        if (numbering) {
            Integer integer = (Integer)this.stack.pop();
            this.index = integer.intValue();
        }
        --this.indent;
    }
    
}



