/*
       Licensed to the Apache Software Foundation (ASF) under one
       or more contributor license agreements.  See the NOTICE file
       distributed with this work for additional information
       regarding copyright ownership.  The ASF licenses this file
       to you under the Apache License, Version 2.0 (the
       "License"); you may not use this file except in compliance
       with the License.  You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing,
       software distributed under the License is distributed on an
       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
       KIND, either express or implied.  See the License for the
       specific language governing permissions and limitations
       under the License
*/
/*
 * RegionTest.java
 * JUnit based test
 *
 * Created on 27 febbraio 2003, 22.07
 *  @author Valter Crescenzi
 */

package roadrunner;

import java.util.*;
import junit.framework.*;

import roadrunner.ast.*;
import roadrunner.parser.*;
import roadrunner.util.Util;
import roadrunner.util.Indenter;

public class RegionTest extends TestCase {
  
  private Expression exp;
  private ExpressionRegion HookC;
  private ExpressionRegion B;
  private ExpressionRegion AC;
  
  public RegionTest(java.lang.String testName) {
    super(testName);

    this.exp = ASTBuilderTest.getFixExpression();
    System.out.println(exp.getRoot().dump(new Indenter(">")));
    
    this.HookC = new ExpressionRegion(this.exp,Node.EMPTY_PATH, 1, 3);
    this.AC = new ExpressionRegion(this.exp,Node.EMPTY_PATH, 0, 3);
    int[] toand = {1,0}; 
    this.B = new ExpressionRegion(this.exp,new PathArray(toand),0,1);
  }
  
  public static void main(java.lang.String[] args) {
    junit.textui.TestRunner.run(suite());
  }
  
  public static Test suite() {
    TestSuite suite = new TestSuite(RegionTest.class);
    
    return suite;
  }
  
  /** Test of getBase method, of class roadrunner.ast.Region. */
  public void testGetBase() {
    System.out.println("testGetBase");
    
    assertEquals(this.exp.getRoot().jjtGetChild(1).jjtGetChild(0), this.B.getBase(this.exp));
    assertEquals(this.exp.getRoot(), this.HookC.getBase());
    assertEquals(this.exp.getRoot(), this.AC.getBase(this.exp));
  }
  
  /** Test of getBasePath method, of class roadrunner.ast.Region. */
  public void testGetBasePath() {
    System.out.println("testGetBasePath");
    int cmpInd[] = {1,0};
    assertEquals(cmpInd[0], this.B.getBasePath().indices()[0]);
    assertEquals(cmpInd[1], this.B.getBasePath().indices()[1]);
    assertEquals(Node.EMPTY_PATH, this.HookC.getBasePath());
    assertEquals(Node.EMPTY_PATH, this.AC.getBasePath());    
  }
  
  /** Test of getLeft/RightBorderPos method, of class roadrunner.ast.Region. */
  public void testGetBorderPos() {
    System.out.println("testGetLeft&RightBorderPos");
    
    assertEquals(0, this.B.getLeftBorderPos());
    assertEquals(1, this.B.getRightBorderPos());
  }
  
  /** Test of asList method, of class roadrunner.ast.Region. */
  public void testAsList() {
    System.out.println("testAsList");
    
    assertEquals(3, this.AC.asList(this.exp).size());
    assertEquals(2, this.HookC.asList(this.exp).size());
    assertEquals(1, this.B.asList(this.exp).size());
  }
  
  
}
