/*
       Licensed to the Apache Software Foundation (ASF) under one
       or more contributor license agreements.  See the NOTICE file
       distributed with this work for additional information
       regarding copyright ownership.  The ASF licenses this file
       to you under the Apache License, Version 2.0 (the
       "License"); you may not use this file except in compliance
       with the License.  You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing,
       software distributed under the License is distributed on an
       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
       KIND, either express or implied.  See the License for the
       specific language governing permissions and limitations
       under the License
*/
/*
 * PreferencesTest.java
 * JUnit based test
 *
 * Created on 23 febbraio 2003, 17.56
 * @author Valter Crescenzi
 */

package roadrunner.config;

import junit.framework.*;

import java.util.*;
import java.util.logging.*;
import java.io.*;
import javax.xml.parsers.*;

import org.w3c.dom.*;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

import roadrunner.config.Constants;

public class PreferencesTest extends TestCase implements Constants {
  
  final static private String prefsDir = "/home/crescenz/RoadRunner/current/test/fix/preferences/";
  final static private String upfn = prefsDir+"u.xml";
  
  private Preferences prefs;
  
  public void setUp() throws Exception {
    prefs = new Preferences();
    prefs.load(new File(upfn));
  }
  
  public PreferencesTest(java.lang.String testName) {
    super(testName);
  }
  
  public static void main(java.lang.String[] args) {
    junit.textui.TestRunner.run(suite());
  }
  
  public static Test suite() {
    TestSuite suite = new TestSuite(PreferencesTest.class);
    
    return suite;
  }
  
  /** Test of contains method, of class roadrunner.Preferences. */
  public void testContains() {
    System.out.println("testContains");
    
    assertTrue(this.prefs.contains(FREE_TEXT));
    assertTrue(!this.prefs.contains(MAX_NUM_OCCUR));
  }
  
  
  /** Test of getBoolean method, of class roadrunner.Preferences. */
  public void testGetBoolean() {
    System.out.println("testGetBoolean");
    
    assertTrue(this.prefs.getBoolean(FREE_TEXT));
  }

  /** Test of getString method, of class roadrunner.Preferences. */
  public void testGetString() {
    System.out.println("testGetString");
    
    assertEquals(this.prefs.getString(BROWSER),"mozilla");
  }
  
  /** Test of getSet method, of class roadrunner.Preferences. */
  public void testGetSet() {
    System.out.println("testGetSet");
    String [] pTags = {"sup","p","i","a"};
    assertEquals(this.prefs.getSet(FREETEXT_TAGS), new HashSet(Arrays.asList(pTags)));
    assertEquals(this.prefs.getSet(IGNORE_TAGS), Collections.EMPTY_SET);
    
    assertEquals(Config.getPrefs().getSet(IGNORE_TAGS), Collections.EMPTY_SET);    
  }
    
  /** Test of saveAs method, of class roadrunner.Preferences. */
  public void testSaveAs() throws IOException {
    System.out.println("testSaveAs");
    File file = new File(prefsDir+"testprefs.xml");
    file.deleteOnExit();
    this.prefs.saveAs(file);
    Preferences saved = this.prefs;
    Preferences loaded = new Preferences();
    loaded.load(file);
    assertEquals(saved.getBoolean(AMBIGUITY),loaded.getBoolean(AMBIGUITY));
    assertEquals(saved.getSet(IGNORE_TAGS),loaded.getSet(IGNORE_TAGS));
  }
  
    /** Test of default values handling, of class roadrunner.Preferences. */
  public void testDefaultsHandling() {
    System.out.println("testDefaultsHandling");

    assertEquals(Config.getPrefs().getInt(MAX_NUM_OCCUR),4);
  }

}
