/*
       Licensed to the Apache Software Foundation (ASF) under one
       or more contributor license agreements.  See the NOTICE file
       distributed with this work for additional information
       regarding copyright ownership.  The ASF licenses this file
       to you under the Apache License, Version 2.0 (the
       "License"); you may not use this file except in compliance
       with the License.  You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing,
       software distributed under the License is distributed on an
       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
       KIND, either express or implied.  See the License for the
       specific language governing permissions and limitations
       under the License
*/
/*
 * CharacteristicSamplerTest.java
 * JUnit based test
 *
 * Created on 2 aprile 2003, 15.09
 * @author Valter Crescenzi
 */

package roadrunner.engine.sampler;

import junit.framework.*;

import java.io.*;
import java.util.*;
import java.util.logging.*;

import roadrunner.bidi.Direction;
import roadrunner.bidi.Region;
import roadrunner.ast.*;
import roadrunner.parser.Parser;
import roadrunner.parser.Token;
import roadrunner.parser.TokenList;
import roadrunner.Wrapper;

import roadrunner.FixtureOnFile;

public class CharacteristicSamplerTest extends TestCase {
    
    private final static Logger log = Logger.getLogger(CharacteristicSamplerTest.class.getName());
    
    private static String wfn = "rufusWithSubtree.xml";
    
    public CharacteristicSamplerTest(java.lang.String testName) {
        super(testName);
    }
    
    public static void main(java.lang.String[] args) {
        junit.textui.TestRunner.run(suite());
    }
    
    public static Test suite() {
        TestSuite suite = new TestSuite(CharacteristicSamplerTest.class);
        
        return suite;
    }
    
    /** Test of getCharacteristicSampleIterator method, of class roadrunner.engine.CharacteristicSampler. */
    public void testGetCharacteristicSampleIterator() throws Exception {
        System.out.println("testGetCharacteristicSampleIterator");
        
        Wrapper wrapper = Wrapper.load(FixtureOnFile.getWrapperFile(wfn));
        Parser parserlr = new Parser(wrapper.getExpression(),Direction.LEFT2RIGHT);
        Parser parserrl = new Parser(wrapper.getExpression(),Direction.RIGHT2LEFT);
        CharacteristicSet samples = new CharacteristicSet(wrapper.getExpression());
        Iterator it = samples.listIterator();
        int c=0;
        while (it.hasNext()) {
            TokenList tl = (TokenList)it.next();
            log.info("sample "+c+"\n");
            log.info(tl.getTokens().toString());
            assertTrue(parserlr.parse(tl));
            assertTrue(parserrl.parse(tl));
            c++;
        }
        assertEquals(2,c);
        
    }
    
    
    // Add test methods here, they have to start with 'test' name.
    // for example:
    // public void testHello() {}
    
    
    
}
