/*
       Licensed to the Apache Software Foundation (ASF) under one
       or more contributor license agreements.  See the NOTICE file
       distributed with this work for additional information
       regarding copyright ownership.  The ASF licenses this file
       to you under the Apache License, Version 2.0 (the
       "License"); you may not use this file except in compliance
       with the License.  You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing,
       software distributed under the License is distributed on an
       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
       KIND, either express or implied.  See the License for the
       specific language governing permissions and limitations
       under the License
*/
/*
 * addPlus_wTest.java
 * JUnit based test
 *
 * Created on 2 aprile 2003, 13.21
 * @author Valter Crescenzi
 */

package roadrunner.engine.space.operator;

import junit.framework.*;

import java.net.URL;
import java.util.*;
import java.util.logging.*;

import roadrunner.util.Util;
import roadrunner.bidi.Region;
import roadrunner.ast.Expression;
import roadrunner.ast.ExpressionRegion;
import roadrunner.config.Config;
import roadrunner.parser.*;
import roadrunner.Sample;

import roadrunner.FixtureOnFile;

public class addPlus_sTest extends TestCase {
    
    private final static Logger log = Logger.getLogger(addPlus_sTest.class.getName());
    
    private Sample sample_pls1;
    private Sample sample_pls2;
    
    private static String pls1 = "basic-nest1-plus1.xhtml";
    private static String pls2 = "basic-nest1-plus2.xhtml";
    
    private addPlus_s addplus;
    
    public void setUp() {
        Expression expression = new Expression(sample_pls1.getTokenlist());
        TokenList tokenlist = sample_pls2.getTokenlist();
        
        Parser parser = new Parser(expression);
        parser.parsePrefix(tokenlist);
        List mismatches = parser.getMismatches();
        assertEquals(1, mismatches.size());
        MismatchPoint mismatch = (MismatchPoint)mismatches.get(0);
        List operators = addPlus_s.getFactory(mismatch).createOperators();
        assertEquals(1,operators.size());
        this.addplus = (addPlus_s)operators.get(0);
    }
    
    public addPlus_sTest(java.lang.String testName) throws Exception {
        super(testName);
        this.sample_pls1 = new Sample(new URL("file:"+FixtureOnFile.getBasicFile(pls1)), Config.getPrefs());
        this.sample_pls2 = new Sample(new URL("file:"+FixtureOnFile.getBasicFile(pls2)), Config.getPrefs());
    }
    
    public static void main(java.lang.String[] args) {
        junit.textui.TestRunner.run(suite());
    }
    
    public static Test suite() {
        TestSuite suite = new TestSuite(addPlus_wTest.class);
        
        return suite;
    }
    
    /** Test of getRegionAfterSquare method, of class roadrunner.engine.addPlus_w. */
    public void testGetRegionAfterSquare() {
        System.out.println("testGetRegionAfterSquare");
        
        TokenListRegion afterSquare = (TokenListRegion)this.addplus.getRegionAfterSquare();
        Token first =(Token)afterSquare.asList().get(0);
        log.info(afterSquare.asList().toString());
        assertEquals("ul",first.getElement());
    }
    
    
    /** Test of next method, of class roadrunner.engine.addPlus_w. */
    public void testNext() {
        System.out.println("testNext");
        
        Expression result = this.addplus.next();
        
        log.info(result.dump(""));
        
        assertTrue(new Parser(result).parsePrefix(this.sample_pls2.getTokenlist())>0);
    }
    
}
