/*
       Licensed to the Apache Software Foundation (ASF) under one
       or more contributor license agreements.  See the NOTICE file
       distributed with this work for additional information
       regarding copyright ownership.  The ASF licenses this file
       to you under the Apache License, Version 2.0 (the
       "License"); you may not use this file except in compliance
       with the License.  You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing,
       software distributed under the License is distributed on an
       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
       KIND, either express or implied.  See the License for the
       specific language governing permissions and limitations
       under the License
*/
/*
 * TokenFactoryTest.java
 * JUnit based test
 *
 * Created on 12 marzo 2003, 11.24
 *@author Valter Crescenzi
 */

package roadrunner.parser.token;

import junit.framework.*;

import java.util.*;

import org.w3c.dom.*;

import roadrunner.util.Util;
import roadrunner.parser.Token;

public class TokenFactoryTest extends TestCase {
  
  public TokenFactoryTest(java.lang.String testName) {
    super(testName);
  }
  
  public static void main(java.lang.String[] args) {
    junit.textui.TestRunner.run(suite());
  }
  
  public static Test suite() {
    TestSuite suite = new TestSuite(TokenFactoryTest.class);
    
    return suite;
  }
  
  /** Test of createOpenTagToken method, of class roadrunner.parser.TokenFactory. */
  public void testCreateOpenTagToken() {
    System.out.println("testCreateOpenTagToken");
    
    TokenFactory factory = TokenFactory.getInstance();
    Map atts = new HashMap(); atts.put("href","http://boh");
    Map atts2 = new HashMap(); atts2.put("href","http://boh2");
    Token tag1 = factory.createOpenTagToken("a", Collections.EMPTY_MAP, 0);
    Token tag2 = factory.createOpenTagToken("a", Collections.EMPTY_MAP,0);
    Token tag3 = factory.createOpenTagToken("a",atts,0);
    Token tag4 = factory.createOpenTagToken("a",atts,1);
    Token tag5 = factory.createOpenTagToken("a",atts2,1);
    assertTrue(tag1==tag2);
    assertTrue(tag1!=tag3);
    assertTrue(tag3.getAttributes().containsKey("href"));
    assertTrue(tag4!=tag3);   
    assertTrue(tag5!=tag4); // possible variants
    assertEquals(tag4.getAttributes().get("href"), "http://boh");
    assertEquals(tag5.getAttributes().get("href"), "http://boh2");
  } 
  
  /** Test of createCloseTagToken method, of class roadrunner.parser.TokenFactory. */
  public void testCreateCloseTagToken() {
    System.out.println("testCreateCloseTagToken");
    TokenFactory factory = TokenFactory.getInstance();
    assertEquals(
    -(factory.createOpenTagToken("boh", Collections.EMPTY_MAP, 0)).code(), 
     (factory.createCloseTagToken("boh", Collections.EMPTY_MAP, 0)).code());
  }

}
